use strict;
use warnings;
use Test::More;
use lib qw(./lib ./blib/lib);
require './t/600-lhost-code';

my $enginename = 'V5sendmail';
my $samplepath = sprintf("./set-of-emails/private/lhost-%s", lc $enginename);
my $enginetest = Sisimai::Lhost::Code->makeinquiry;
my $isexpected = {
    # INDEX => [['D.S.N.', 'replycode', 'REASON', 'hardbounce'], [...]]
    '1001'  => [['5.0.911', '550', 'userunknown',     1]],
    '1002'  => [['5.0.911', '550', 'userunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1]], # invalid domain name
    '1003'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1004'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1005'  => [['5.0.911', '550', 'userunknown',     1],
                ['5.0.911', '550', 'userunknown',     1],
                ['5.0.911', '550', 'userunknown',     1],
                ['5.0.911', '550', 'userunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1]],
    '1006'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1007'  => [['5.0.911', '550', 'userunknown',     1],
                ['5.0.911', '550', 'userunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1]],
    '1008'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1009'  => [['5.0.911', '550', 'userunknown',     1],
                ['5.0.911', '550', 'userunknown',     1]],
    '1010'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1011'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1012'  => [['5.0.911', '550', 'userunknown',     1]],
    '1013'  => [['5.0.911', '550', 'userunknown',     1]],
    '1014'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1015'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1016'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1017'  => [['5.0.911', '550', 'userunknown',     1]],
    '1018'  => [['5.0.911', '550', 'userunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1]],
    '1019'  => [['5.0.910', '550', 'filtered',        0]],
    '1020'  => [['5.0.911', '550', 'userunknown',     1]],
    '1021'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1022'  => [['5.0.911', '550', 'userunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1]],
    '1023'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1024'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1025'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1026'  => [['5.0.911', '550', 'userunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1],  # invalid domain name
                ['5.0.912', '550', 'hostunknown',     1]],
    '1027'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1028'  => [['5.0.973', '550', 'requireptr',      0],
                ['5.0.911', '550', 'userunknown',     1]],
    '1029'  => [['5.0.911', '550', 'userunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1]],
    '1030'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1031'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1032'  => [['5.0.911', '550', 'userunknown',     1]],
    '1033'  => [['5.0.911', '550', 'userunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1]],
    '1034'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1035'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1036'  => [['5.0.911', '550', 'userunknown',     1],
                ['5.0.911', '550', 'userunknown',     1]],
    '1037'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1038'  => [['5.0.911', '550', 'userunknown',     1],
                ['5.0.911', '550', 'userunknown',     1]],
    '1039'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1040'  => [['5.0.912', '550', 'hostunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1]],
    '1041'  => [['5.0.911', '550', 'userunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1]],
    '1042'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1043'  => [['5.0.911', '550', 'userunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1]],
    '1044'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1045'  => [['5.0.911', '550', 'userunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1]],
    '1046'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1047'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1048'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1049'  => [['5.0.911', '550', 'userunknown',     1]],
    '1050'  => [['5.0.971', '553', 'blocked',         0]],
    '1051'  => [['5.0.911', '550', 'userunknown',     1],
                ['5.0.911', '550', 'userunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1]], # invalid domain name
    '1052'  => [['5.0.971', '550', 'blocked',         0],
                ['5.0.912', '550', 'hostunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1],
                ['5.0.911', '550', 'userunknown',     1]],
    '1053'  => [['5.0.911', '550', 'userunknown',     1]],
    '1054'  => [['5.0.911', '550', 'userunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1],
                ['5.0.911', '550', 'userunknown',     1]],
    '1055'  => [['5.0.911', '550', 'userunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1]],
    '1056'  => [['5.0.911', '550', 'userunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1]],
    '1057'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1058'  => [['5.0.911', '550', 'userunknown',     1]],
    '1059'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1060'  => [['5.0.911', '550', 'userunknown',     1]],
    '1061'  => [['5.0.911', '550', 'userunknown',     1]],
    '1064'  => [['5.0.911', '550', 'userunknown',     1]],
    '1065'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1066'  => [['5.0.911', '550', 'userunknown',     1],
                ['5.7.1',   '550', 'norelaying',      0]],
    '1067'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1068'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1069'  => [['5.0.910', '550', 'filtered',        0]],
    '1071'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1072'  => [['5.0.911', '550', 'userunknown',     1],
                ['5.0.911', '550', 'userunknown',     1]],
    '1073'  => [['5.0.911', '550', 'userunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1]],
    '1074'  => [['5.0.911', '550', 'userunknown',     1]],
    '1075'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1076'  => [['5.0.911', '550', 'userunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1]],
    '1077'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1078'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1079'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1080'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1081'  => [['5.0.911', '550', 'userunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1]],
    '1082'  => [['5.0.911', '550', 'userunknown',     1]],
    '1083'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1084'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1085'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1086'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1087'  => [['5.0.911', '550', 'userunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1]],
    '1088'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1089'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1090'  => [['5.0.911', '550', 'userunknown',     1]],
    '1091'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1092'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1093'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1094'  => [['5.0.911', '550', 'userunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1]],
    '1095'  => [['5.0.911', '550', 'userunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1]],
    '1096'  => [['5.0.911', '550', 'userunknown',     1],
                ['5.0.911', '550', 'userunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1]],
    '1097'  => [['5.0.911', '550', 'userunknown',     1],
                ['5.0.911', '550', 'userunknown',     1]],
    '1098'  => [['5.0.911', '550', 'userunknown',     1]],
    '1100'  => [['5.0.911', '550', 'userunknown',     1]],
    '1101'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1102'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1103'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1104'  => [['5.0.911', '550', 'userunknown',     1]],
    '1105'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1106'  => [['5.0.911', '550', 'userunknown',     1],
                ['5.0.911', '550', 'userunknown',     1]],
    '1107'  => [['5.0.911', '550', 'userunknown',     1]],
    '1108'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1109'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1110'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1111'  => [['5.0.911', '550', 'userunknown',     1]],
    '1112'  => [['5.0.911', '550', 'userunknown',     1]],
    '1113'  => [['4.0.971', '421', 'blocked',         0]],
    '1114'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1115'  => [['4.0.944', '421', 'networkerror',    0]],
    '1116'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1117'  => [['4.0.973', '421', 'requireptr',      0]],
    '1118'  => [['5.0.911', '550', 'userunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1]],
    '1119'  => [['4.0.947', '421', 'expired',         0]],
    '1120'  => [['5.0.911', '550', 'userunknown',     1]],
    '1121'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1122'  => [['4.0.971', '421', 'blocked',         0]],
    '1123'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1124'  => [['4.0.947', '421', 'expired',         0]],
    '1125'  => [['4.0.947', '421', 'expired',         0]],
    '1126'  => [['5.0.911', '550', 'userunknown',     1]],
    '1127'  => [['4.0.947', '421', 'expired',         0]],
    '1128'  => [['5.0.909', '550', 'norelaying',      0]],
    '1129'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1130'  => [['4.0.947', '421', 'expired',         0]],
    '1131'  => [['5.0.911', '550', 'userunknown',     1]],
    '1132'  => [['5.0.910', '550', 'filtered',        0]],
    '1133'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1134'  => [['4.0.947', '421', 'expired',         0]],
    '1135'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1136'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1137'  => [['5.0.911', '550', 'userunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1]],
    '1138'  => [['5.0.911', '550', 'userunknown',     1]],
    '1139'  => [['5.0.911', '550', 'userunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1]],
    '1140'  => [['5.0.911', '550', 'userunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1]],
    '1141'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1142'  => [['5.0.911', '550', 'userunknown',     1]],
    '1143'  => [['5.0.912', '550', 'hostunknown',     1]],
    '1144'  => [['5.0.911', '550', 'userunknown',     1],
                ['5.0.912', '550', 'hostunknown',     1],
                ['5.0.911', '550', 'userunknown',     1]],
};

plan 'skip_all', sprintf("%s not found", $samplepath) unless -d $samplepath;
$enginetest->($enginename, $isexpected, 1, 0);
done_testing;

